__author__ = 'weijia'


TEXT_LENGTH_16 = 16
TEXT_LENGTH_32 = 32
TEXT_LENGTH_64 = 64
TEXT_LENGTH_128 = 128
TEXT_LENGTH_256 = 256
TEXT_LENGTH_512 = 512
TEXT_LENGTH_1024 = 1024
TEXT_LENGTH_2048 = 2048
TEXT_LENGTH_4096 = 4096
TEXT_LENGTH_8092 = 8092
TEXT_LENGTH_16184 = 16184
TEXT_LENGTH_32368 = 32368
